///<reference path="../../.d.ts"/>
"use strict";
var path = require("path");
var temp = require("temp");
var LiveSyncCommands = (function () {
    function LiveSyncCommands() {
    }
    LiveSyncCommands.DeployProjectCommand = function (liveSyncUrl) {
        return "DeployProject " + liveSyncUrl + " \r";
    };
    LiveSyncCommands.ReloadStartViewCommand = function () {
        return "ReloadStartView \r";
    };
    LiveSyncCommands.SyncFilesCommand = function () {
        return "SyncFiles \r";
    };
    LiveSyncCommands.RefreshCurrentViewCommand = function () {
        return "RefreshCurrentView \r";
    };
    return LiveSyncCommands;
})();
var AndroidLiveSyncService = (function () {
    function AndroidLiveSyncService(device, $fs, $mobileHelper) {
        this.device = device;
        this.$fs = $fs;
        this.$mobileHelper = $mobileHelper;
    }
    Object.defineProperty(AndroidLiveSyncService.prototype, "liveSyncCommands", {
        get: function () {
            return LiveSyncCommands;
        },
        enumerable: true,
        configurable: true
    });
    AndroidLiveSyncService.prototype.livesync = function (appIdentifier, liveSyncRoot, commands) {
        var _this = this;
        return (function () {
            var commandsFileDevicePath = _this.$mobileHelper.buildDevicePath(liveSyncRoot, AndroidLiveSyncService.COMMANDS_FILE);
            _this.createCommandsFileOnDevice(commandsFileDevicePath, commands).wait();
            _this.device.adb.sendBroadcastToDevice(AndroidLiveSyncService.LIVESYNC_BROADCAST_NAME, { "app-id": appIdentifier }).wait();
        }).future()();
    };
    AndroidLiveSyncService.prototype.createCommandsFileOnDevice = function (commandsFileDevicePath, commands) {
        var _this = this;
        return (function () {
            var hostTmpDir = _this.getTempDir();
            var commandsFileHostPath = path.join(hostTmpDir, AndroidLiveSyncService.COMMANDS_FILE);
            _this.$fs.writeFile(commandsFileHostPath, commands.join("\n")).wait();
            _this.device.fileSystem.transferFile(commandsFileHostPath, commandsFileDevicePath).wait();
            _this.device.adb.executeShellCommand(["chmod", "0777", ("" + commandsFileDevicePath)]).wait();
        }).future()();
    };
    AndroidLiveSyncService.prototype.getTempDir = function () {
        temp.track();
        return temp.mkdirSync("ab-");
    };
    AndroidLiveSyncService.COMMANDS_FILE = "telerik.livesync.commands";
    AndroidLiveSyncService.LIVESYNC_BROADCAST_NAME = "com.telerik.LiveSync";
    return AndroidLiveSyncService;
})();
exports.AndroidLiveSyncService = AndroidLiveSyncService;
